@@ -42,6 +42,7 @@
 #include <QQuickItem>
 #include <QQuickWindow>
 #include <QTimer>
+#include <QScreen>
 #include <qplatformdefs.h>
 
 #include <KAuthorized>
@@ -239,6 +240,22 @@ QHash<int, QByteArray> FolderModel::staticRoleNames()
     return roleNames;
 }
 
+void FolderModel::setMenuPos()
+{
+    QPoint pos = QCursor::pos();
+    QScreen *screen = nullptr;
+    for (auto *s : qApp->screens()) {
+        if (s->geometry().contains(pos)) {
+            screen = s;
+            break;
+        }
+    }
+    if (screen) {
+        pos -= screen->geometry().topLeft();
+    }
+    m_menuPosition = pos;
+}
+
 void FolderModel::classBegin()
 {
 }
@@ -1692,7 +1709,7 @@ void FolderModel::updateActions()
         m_newMenu->checkUpToDate();
         m_newMenu->setPopupFiles(QList<QUrl>() << m_dirModel->dirLister()->url());
         // we need to set here as well, when the menu is shown via AppletInterface::eventFilter
-        m_menuPosition = QCursor::pos();
+        setMenuPos();
 
         if (QAction *newMenuAction = m_actionCollection.action(QStringLiteral("newMenu"))) {
             newMenuAction->setEnabled(itemProperties.supportsWriting());
@@ -1855,18 +1872,16 @@ void FolderModel::openContextMenu(QQuickItem *visualParent, Qt::KeyboardModifier
         }
     }
 
-    if (visualParent) {
-        m_menuPosition = visualParent->mapToGlobal(QPointF(0, visualParent->height())).toPoint();
-    } else {
-        m_menuPosition = QCursor::pos();
+    menu->setAttribute(Qt::WA_TranslucentBackground);
+    menu->winId(); // force surface creation before ensurePolish call in menu::Popup which happens before show
+
+    if (visualParent && menu->windowHandle()) {
+        menu->windowHandle()->setTransientParent(visualParent->window());
     }
 
     // Used to monitor Shift modifier usage while the menu is open, to
     // swap the Trash and Delete actions.
     menu->installEventFilter(this);
-
-    menu->setAttribute(Qt::WA_TranslucentBackground);
-    menu->winId(); // force surface creation before ensurePolish call in menu::Popup which happens before show
     menu->popup(m_menuPosition);
     connect(menu, &QMenu::aboutToHide, [menu]() {
         menu->deleteLater();
